<?php

namespace ServiceType;

use \WsdlToPhp\PackageBase\AbstractSoapClientBase;

/**
 * This class stands for Car ServiceType
 * @subpackage Services
 */
class Car extends AbstractSoapClientBase
{
    /**
     * Sets the HeaderLogin SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param \StructType\HeaderLoginType $headerLogin
     * @param string $nameSpace
     * @param bool $mustUnderstand
     * @param string $actor
     * @return bool
     */
    public function setSoapHeaderHeaderLogin(\StructType\HeaderLoginType $headerLogin, $nameSpace = 'http://www.webservices.nl/soap/', $mustUnderstand = false, $actor = null)
    {
        return $this->setSoapHeader($nameSpace, 'HeaderLogin', $headerLogin, $mustUnderstand, $actor);
    }
    /**
     * Sets the HeaderAuthenticate SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param \StructType\HeaderAuthenticateType $headerAuthenticate
     * @param string $nameSpace
     * @param bool $mustUnderstand
     * @param string $actor
     * @return bool
     */
    public function setSoapHeaderHeaderAuthenticate(\StructType\HeaderAuthenticateType $headerAuthenticate, $nameSpace = 'http://www.webservices.nl/soap/', $mustUnderstand = false, $actor = null)
    {
        return $this->setSoapHeader($nameSpace, 'HeaderAuthenticate', $headerAuthenticate, $mustUnderstand, $actor);
    }
    /**
     * Method to call the operation originally named carRDWCarCheckCode
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Check the validity of a license plate and check code ('meldcode') combination
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\CarRDWCarCheckCodeRequestType $parameters
     * @return \StructType\CarRDWCarCheckCodeResponseType|bool
     */
    public function carRDWCarCheckCode(\StructType\CarRDWCarCheckCodeRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->carRDWCarCheckCode($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named carRDWCarDataV3
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieves data of a car with a Dutch license plate, including a list of types matched if more information is available.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\CarRDWCarDataV3RequestType $parameters
     * @return \StructType\CarRDWCarDataV3ResponseType|bool
     */
    public function carRDWCarDataV3(\StructType\CarRDWCarDataV3RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->carRDWCarDataV3($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named carRDWCarDataBPV2
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Find a specific Dutch car's data, including BPM and power and types
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\CarRDWCarDataBPV2RequestType $parameters
     * @return \StructType\CarRDWCarDataBPV2ResponseType|bool
     */
    public function carRDWCarDataBPV2(\StructType\CarRDWCarDataBPV2RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->carRDWCarDataBPV2($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named carRDWCarDataExtended
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Find a specific Dutch car's data, including European Approval Mark
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\CarRDWCarDataExtendedRequestType $parameters
     * @return \StructType\CarRDWCarDataExtendedResponseType|bool
     */
    public function carRDWCarDataExtended(\StructType\CarRDWCarDataExtendedRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->carRDWCarDataExtended($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named carRDWCarDataPrice
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieves data of a car with a Dutch license plate, including catalog price.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\CarRDWCarDataPriceRequestType $parameters
     * @return \StructType\CarRDWCarDataPriceResponseType|bool
     */
    public function carRDWCarDataPrice(\StructType\CarRDWCarDataPriceRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->carRDWCarDataPrice($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named carRDWCarDataOptions
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Find a specific Dutch car's data, including information about extra options
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\CarRDWCarDataOptionsRequestType $parameters
     * @return \StructType\CarRDWCarDataOptionsResponseType|bool
     */
    public function carRDWCarDataOptions(\StructType\CarRDWCarDataOptionsRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->carRDWCarDataOptions($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named carVWEMeldcodeCheck
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Check the validity of a license plate and check code ('meldcode') combination
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\CarVWEMeldcodeCheckRequestType $parameters
     * @return \StructType\CarVWEMeldcodeCheckResponseType|bool
     */
    public function carVWEMeldcodeCheck(\StructType\CarVWEMeldcodeCheckRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->carVWEMeldcodeCheck($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named carVWEBasicTypeData
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\CarVWEBasicTypeDataRequestType $parameters
     * @return \StructType\CarVWEBasicTypeDataResponseType|bool
     */
    public function carVWEBasicTypeData(\StructType\CarVWEBasicTypeDataRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->carVWEBasicTypeData($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named carVWEVersionPrice
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\CarVWEVersionPriceRequestType $parameters
     * @return \StructType\CarVWEVersionPriceResponseType|bool
     */
    public function carVWEVersionPrice(\StructType\CarVWEVersionPriceRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->carVWEVersionPrice($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named carVWEOptions
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieve options of a specific model of a car
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\CarVWEOptionsRequestType $parameters
     * @return \StructType\CarVWEOptionsResponseType|bool
     */
    public function carVWEOptions(\StructType\CarVWEOptionsRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->carVWEOptions($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named carVWEListBrands
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\CarVWEListBrandsRequestType $parameters
     * @return \StructType\CarVWEListBrandsResponseType|bool
     */
    public function carVWEListBrands(\StructType\CarVWEListBrandsRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->carVWEListBrands($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named carVWEListModels
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\CarVWEListModelsRequestType $parameters
     * @return \StructType\CarVWEListModelsResponseType|bool
     */
    public function carVWEListModels(\StructType\CarVWEListModelsRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->carVWEListModels($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named carVWEListVersions
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\CarVWEListVersionsRequestType $parameters
     * @return \StructType\CarVWEListVersionsResponseType|bool
     */
    public function carVWEListVersions(\StructType\CarVWEListVersionsRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->carVWEListVersions($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named carVWEVersionYearData
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\CarVWEVersionYearDataRequestType $parameters
     * @return \StructType\CarVWEVersionYearDataResponseType|bool
     */
    public function carVWEVersionYearData(\StructType\CarVWEVersionYearDataRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->carVWEVersionYearData($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named carVWEPhotos
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieve photos of a specific model of a car
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\CarVWEPhotosRequestType $parameters
     * @return \StructType\CarVWEPhotosResponseType|bool
     */
    public function carVWEPhotos(\StructType\CarVWEPhotosRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->carVWEPhotos($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named carATDPrice
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieve Autodisk price information
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\CarATDPriceRequestType $parameters
     * @return \StructType\CarATDPriceResponseType|bool
     */
    public function carATDPrice(\StructType\CarATDPriceRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->carATDPrice($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named carRDWCarData
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Find a specific Dutch car's data
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\CarRDWCarDataRequestType $parameters
     * @return \StructType\CarRDWCarDataResponseType|bool
     */
    public function carRDWCarData(\StructType\CarRDWCarDataRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->carRDWCarData($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named carRDWCarDataV2
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieves data of a car with a Dutch license plate, including a list of types matched if more information is available.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\CarRDWCarDataV2RequestType $parameters
     * @return \StructType\CarRDWCarDataV2ResponseType|bool
     */
    public function carRDWCarDataV2(\StructType\CarRDWCarDataV2RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->carRDWCarDataV2($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named carRDWCarDataBP
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Find a specific Dutch car's data, including BPM and power
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\CarRDWCarDataBPRequestType $parameters
     * @return \StructType\CarRDWCarDataBPResponseType|bool
     */
    public function carRDWCarDataBP(\StructType\CarRDWCarDataBPRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->carRDWCarDataBP($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Returns the result
     * @see AbstractSoapClientBase::getResult()
     * @return \StructType\CarATDPriceResponseType|\StructType\CarRDWCarCheckCodeResponseType|\StructType\CarRDWCarDataBPResponseType|\StructType\CarRDWCarDataBPV2ResponseType|\StructType\CarRDWCarDataExtendedResponseType|\StructType\CarRDWCarDataOptionsResponseType|\StructType\CarRDWCarDataPriceResponseType|\StructType\CarRDWCarDataResponseType|\StructType\CarRDWCarDataV2ResponseType|\StructType\CarRDWCarDataV3ResponseType|\StructType\CarVWEBasicTypeDataResponseType|\StructType\CarVWEListBrandsResponseType|\StructType\CarVWEListModelsResponseType|\StructType\CarVWEListVersionsResponseType|\StructType\CarVWEMeldcodeCheckResponseType|\StructType\CarVWEOptionsResponseType|\StructType\CarVWEPhotosResponseType|\StructType\CarVWEVersionPriceResponseType|\StructType\CarVWEVersionYearDataResponseType
     */
    public function getResult()
    {
        return parent::getResult();
    }
}
