<?php

namespace ServiceType;

use \WsdlToPhp\PackageBase\AbstractSoapClientBase;

/**
 * This class stands for Graydon ServiceType
 * @subpackage Services
 */
class Graydon extends AbstractSoapClientBase
{
    /**
     * Sets the HeaderLogin SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param \StructType\HeaderLoginType $headerLogin
     * @param string $nameSpace
     * @param bool $mustUnderstand
     * @param string $actor
     * @return bool
     */
    public function setSoapHeaderHeaderLogin(\StructType\HeaderLoginType $headerLogin, $nameSpace = 'http://www.webservices.nl/soap/', $mustUnderstand = false, $actor = null)
    {
        return $this->setSoapHeader($nameSpace, 'HeaderLogin', $headerLogin, $mustUnderstand, $actor);
    }
    /**
     * Sets the HeaderAuthenticate SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param \StructType\HeaderAuthenticateType $headerAuthenticate
     * @param string $nameSpace
     * @param bool $mustUnderstand
     * @param string $actor
     * @return bool
     */
    public function setSoapHeaderHeaderAuthenticate(\StructType\HeaderAuthenticateType $headerAuthenticate, $nameSpace = 'http://www.webservices.nl/soap/', $mustUnderstand = false, $actor = null)
    {
        return $this->setSoapHeader($nameSpace, 'HeaderAuthenticate', $headerAuthenticate, $mustUnderstand, $actor);
    }
    /**
     * Method to call the operation originally named graydonCreditGetReport
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieve a Graydon credit report of a company registered in the Netherlands.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\GraydonCreditGetReportRequestType $parameters
     * @return \StructType\GraydonCreditGetReportResponseType|bool
     */
    public function graydonCreditGetReport(\StructType\GraydonCreditGetReportRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->graydonCreditGetReport($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named graydonCreditSearchIdentification
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Search international Graydon credit report databases for a company using an identifier.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\GraydonCreditSearchIdentificationRequestType $parameters
     * @return \StructType\GraydonCreditSearchIdentificationResponseType|bool
     */
    public function graydonCreditSearchIdentification(\StructType\GraydonCreditSearchIdentificationRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->graydonCreditSearchIdentification($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named graydonCreditSearchName
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Search international Graydon credit report database for a company by name.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\GraydonCreditSearchNameRequestType $parameters
     * @return \StructType\GraydonCreditSearchNameResponseType|bool
     */
    public function graydonCreditSearchName(\StructType\GraydonCreditSearchNameRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->graydonCreditSearchName($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named graydonCreditSearchPostcode
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Search international Graydon credit report database for a company using postcode.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\GraydonCreditSearchPostcodeRequestType $parameters
     * @return \StructType\GraydonCreditSearchPostcodeResponseType|bool
     */
    public function graydonCreditSearchPostcode(\StructType\GraydonCreditSearchPostcodeRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->graydonCreditSearchPostcode($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named graydonCreditQuickscan
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieve a Graydon pd ratings and credit flag of a company registered in the Netherlands.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\GraydonCreditQuickscanRequestType $parameters
     * @return \StructType\GraydonCreditQuickscanResponseType|bool
     */
    public function graydonCreditQuickscan(\StructType\GraydonCreditQuickscanRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->graydonCreditQuickscan($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named graydonCreditRatings
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieve various Graydon credit ratings of a company registered in the Netherlands.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\GraydonCreditRatingsRequestType $parameters
     * @return \StructType\GraydonCreditRatingsResponseType|bool
     */
    public function graydonCreditRatings(\StructType\GraydonCreditRatingsRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->graydonCreditRatings($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named graydonCreditVatNumber
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieve the BTW (VAT) number of a company registered in the Netherlands.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\GraydonCreditVatNumberRequestType $parameters
     * @return \StructType\GraydonCreditVatNumberResponseType|bool
     */
    public function graydonCreditVatNumber(\StructType\GraydonCreditVatNumberRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->graydonCreditVatNumber($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named graydonCreditCompanyLiaisons
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieve top-parent, parent and sibling companies of a company registered in the Netherlands.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\GraydonCreditCompanyLiaisonsRequestType $parameters
     * @return \StructType\GraydonCreditCompanyLiaisonsResponseType|bool
     */
    public function graydonCreditCompanyLiaisons(\StructType\GraydonCreditCompanyLiaisonsRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->graydonCreditCompanyLiaisons($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named graydonCreditManagement
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieve company management credit scores of a company registered in the Netherlands.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\GraydonCreditManagementRequestType $parameters
     * @return \StructType\GraydonCreditManagementResponseType|bool
     */
    public function graydonCreditManagement(\StructType\GraydonCreditManagementRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->graydonCreditManagement($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Returns the result
     * @see AbstractSoapClientBase::getResult()
     * @return \StructType\GraydonCreditCompanyLiaisonsResponseType|\StructType\GraydonCreditGetReportResponseType|\StructType\GraydonCreditManagementResponseType|\StructType\GraydonCreditQuickscanResponseType|\StructType\GraydonCreditRatingsResponseType|\StructType\GraydonCreditSearchIdentificationResponseType|\StructType\GraydonCreditSearchNameResponseType|\StructType\GraydonCreditSearchPostcodeResponseType|\StructType\GraydonCreditVatNumberResponseType
     */
    public function getResult()
    {
        return parent::getResult();
    }
}
