<?php

namespace ServiceType;

use \WsdlToPhp\PackageBase\AbstractSoapClientBase;

/**
 * This class stands for Kadaster ServiceType
 * @subpackage Services
 */
class Kadaster extends AbstractSoapClientBase
{
    /**
     * Sets the HeaderLogin SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param \StructType\HeaderLoginType $headerLogin
     * @param string $nameSpace
     * @param bool $mustUnderstand
     * @param string $actor
     * @return bool
     */
    public function setSoapHeaderHeaderLogin(\StructType\HeaderLoginType $headerLogin, $nameSpace = 'http://www.webservices.nl/soap/', $mustUnderstand = false, $actor = null)
    {
        return $this->setSoapHeader($nameSpace, 'HeaderLogin', $headerLogin, $mustUnderstand, $actor);
    }
    /**
     * Sets the HeaderAuthenticate SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param \StructType\HeaderAuthenticateType $headerAuthenticate
     * @param string $nameSpace
     * @param bool $mustUnderstand
     * @param string $actor
     * @return bool
     */
    public function setSoapHeaderHeaderAuthenticate(\StructType\HeaderAuthenticateType $headerAuthenticate, $nameSpace = 'http://www.webservices.nl/soap/', $mustUnderstand = false, $actor = null)
    {
        return $this->setSoapHeader($nameSpace, 'HeaderAuthenticate', $headerAuthenticate, $mustUnderstand, $actor);
    }
    /**
     * Method to call the operation originally named
     * kadasterEigendomsBerichtDocumentPerceel
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Find a 'Eigendomsbericht' by parcel details. Returns the result in a file of the specified format. If the input matches more than one parcel, a list of the parcels found is returned instead.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterEigendomsBerichtDocumentPerceelRequestType $parameters
     * @return \StructType\KadasterEigendomsBerichtDocumentPerceelResponseType|bool
     */
    public function kadasterEigendomsBerichtDocumentPerceel(\StructType\KadasterEigendomsBerichtDocumentPerceelRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterEigendomsBerichtDocumentPerceel($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * kadasterEigendomsBerichtDocumentPostcode
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Find a 'Eigendomsbericht' by postcode and house number. Returns the result in a file of the specified format. If the input matches more than one parcel, a list of the parcels found is returned instead.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterEigendomsBerichtDocumentPostcodeRequestType $parameters
     * @return \StructType\KadasterEigendomsBerichtDocumentPostcodeResponseType|bool
     */
    public function kadasterEigendomsBerichtDocumentPostcode(\StructType\KadasterEigendomsBerichtDocumentPostcodeRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterEigendomsBerichtDocumentPostcode($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kadasterEigendomsBerichtPerceelV2
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Find a 'Eigendomsbericht' by parcel details. Returns the result as a <BerichtObjectResultaatV2>. In addition to the structured result, a file of the specified format is returned. If the input matches more than one parcel, a list of
     * the parcels found is returned instead.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterEigendomsBerichtPerceelV2RequestType $parameters
     * @return \StructType\KadasterEigendomsBerichtPerceelV2ResponseType|bool
     */
    public function kadasterEigendomsBerichtPerceelV2(\StructType\KadasterEigendomsBerichtPerceelV2RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterEigendomsBerichtPerceelV2($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kadasterEigendomsBerichtPostcodeV2
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Find a 'Eigendomsbericht' by postcode and house number. Returns the result as a <BerichtObjectResultaatV2>. In addition to the structured result, a file of the specified format is returned. If the input matches more than one parcel,
     * a list of the parcels found is returned instead.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterEigendomsBerichtPostcodeV2RequestType $parameters
     * @return \StructType\KadasterEigendomsBerichtPostcodeV2ResponseType|bool
     */
    public function kadasterEigendomsBerichtPostcodeV2(\StructType\KadasterEigendomsBerichtPostcodeV2RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterEigendomsBerichtPostcodeV2($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kadasterKoopsommenOverzichtV2
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a koopsommenoverzicht (in English: real estate transactions overview), which is a list of all transactions of the past five years in the given postcode range.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterKoopsommenOverzichtV2RequestType $parameters
     * @return \StructType\KadasterKoopsommenOverzichtV2ResponseType|bool
     */
    public function kadasterKoopsommenOverzichtV2(\StructType\KadasterKoopsommenOverzichtV2RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterKoopsommenOverzichtV2($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * kadasterUittrekselKadastraleKaartPerceelV3
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a 'Uittreksel Kadastrale Kaart' (a map showing the boundaries of a parcel and buildings on that parcel) in the specified format.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterUittrekselKadastraleKaartPerceelV3RequestType $parameters
     * @return \StructType\KadasterUittrekselKadastraleKaartPerceelV3ResponseType|bool
     */
    public function kadasterUittrekselKadastraleKaartPerceelV3(\StructType\KadasterUittrekselKadastraleKaartPerceelV3RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterUittrekselKadastraleKaartPerceelV3($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * kadasterUittrekselKadastraleKaartPostcodeV3
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a 'Uittreksel Kadastrale Kaart' (a map showing the boundaries of a parcel and buildings on that parcel) in the specified format.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterUittrekselKadastraleKaartPostcodeV3RequestType $parameters
     * @return \StructType\KadasterUittrekselKadastraleKaartPostcodeV3ResponseType|bool
     */
    public function kadasterUittrekselKadastraleKaartPostcodeV3(\StructType\KadasterUittrekselKadastraleKaartPostcodeV3RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterUittrekselKadastraleKaartPostcodeV3($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * kadasterHypothecairBerichtPostcodeV3
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Find a 'Hypothecair bericht' by postcode and house number. If the input matches more than one parcel, a list of the parcels found is returned instead.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterHypothecairBerichtPostcodeV3RequestType $parameters
     * @return \StructType\KadasterHypothecairBerichtPostcodeV3ResponseType|bool
     */
    public function kadasterHypothecairBerichtPostcodeV3(\StructType\KadasterHypothecairBerichtPostcodeV3RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterHypothecairBerichtPostcodeV3($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * kadasterHypothecairBerichtPerceelV3
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Find a 'Hypothecair bericht' by parcel details.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterHypothecairBerichtPerceelV3RequestType $parameters
     * @return \StructType\KadasterHypothecairBerichtPerceelV3ResponseType|bool
     */
    public function kadasterHypothecairBerichtPerceelV3(\StructType\KadasterHypothecairBerichtPerceelV3RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterHypothecairBerichtPerceelV3($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kadasterBronDocument
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Find a 'brondocument', a document which is the basis for an ascription.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterBronDocumentRequestType $parameters
     * @return \StructType\KadasterBronDocumentResponseType|bool
     */
    public function kadasterBronDocument(\StructType\KadasterBronDocumentRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterBronDocument($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kadasterValueListGetRanges
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterValueListGetRangesRequestType $parameters
     * @return \StructType\KadasterValueListGetRangesResponseType|bool
     */
    public function kadasterValueListGetRanges(\StructType\KadasterValueListGetRangesRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterValueListGetRanges($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kadasterValueListGetMunicipalities
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterValueListGetMunicipalitiesRequestType $parameters
     * @return \StructType\KadasterValueListGetMunicipalitiesResponseType|bool
     */
    public function kadasterValueListGetMunicipalities(\StructType\KadasterValueListGetMunicipalitiesRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterValueListGetMunicipalities($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kadasterAddressCoordinates
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns the coordinates of the given address in both the RD system and the latitude/longitude system. The lat/lon coordinates are derived from the RD coordinates.The address may be specified by giving the postcode, house number &
     * house number addition or by giving the cityname, streetname, house number & house number addition.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterAddressCoordinatesRequestType $parameters
     * @return \StructType\KadasterAddressCoordinatesResponseType|bool
     */
    public function kadasterAddressCoordinates(\StructType\KadasterAddressCoordinatesRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterAddressCoordinates($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kadasterKadastraleKaartPerceelV2
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a 'Kadata WMS De Kadastrale Kaart' map in the specified format.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterKadastraleKaartPerceelV2RequestType $parameters
     * @return \StructType\KadasterKadastraleKaartPerceelV2ResponseType|bool
     */
    public function kadasterKadastraleKaartPerceelV2(\StructType\KadasterKadastraleKaartPerceelV2RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterKadastraleKaartPerceelV2($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kadasterKadastraleKaartPostcodeV2
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a 'Kadata WMS De Kadastrale Kaart' map in the specified format.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterKadastraleKaartPostcodeV2RequestType $parameters
     * @return \StructType\KadasterKadastraleKaartPostcodeV2ResponseType|bool
     */
    public function kadasterKadastraleKaartPostcodeV2(\StructType\KadasterKadastraleKaartPostcodeV2RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterKadastraleKaartPostcodeV2($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * kadasterUittrekselKadastraleKaartPerceel
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: This function is deprecated and will not be available in the future. Use "kadasterUittrekselKadastraleKaartPerceelV2" instead.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterUittrekselKadastraleKaartPerceelRequestType $parameters
     * @return \StructType\KadasterUittrekselKadastraleKaartPerceelResponseType|bool
     */
    public function kadasterUittrekselKadastraleKaartPerceel(\StructType\KadasterUittrekselKadastraleKaartPerceelRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterUittrekselKadastraleKaartPerceel($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * kadasterUittrekselKadastraleKaartPostcode
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: This function is deprecated and will not be available in the future. Use "kadasterUittrekselKadastraleKaartPostcodeV2" instead.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterUittrekselKadastraleKaartPostcodeRequestType $parameters
     * @return \StructType\KadasterUittrekselKadastraleKaartPostcodeResponseType|bool
     */
    public function kadasterUittrekselKadastraleKaartPostcode(\StructType\KadasterUittrekselKadastraleKaartPostcodeRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterUittrekselKadastraleKaartPostcode($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kadasterHypothecairBerichtPostcode
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Find a 'Hypothecair bericht' by postcode and house number. If the input matches more than one parcel, a list of the parcels found is returned instead.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterHypothecairBerichtPostcodeRequestType $parameters
     * @return \StructType\KadasterHypothecairBerichtPostcodeResponseType|bool
     */
    public function kadasterHypothecairBerichtPostcode(\StructType\KadasterHypothecairBerichtPostcodeRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterHypothecairBerichtPostcode($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kadasterHypothecairBerichtPerceel
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Find a 'Hypothecair bericht' by parcel details.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterHypothecairBerichtPerceelRequestType $parameters
     * @return \StructType\KadasterHypothecairBerichtPerceelResponseType|bool
     */
    public function kadasterHypothecairBerichtPerceel(\StructType\KadasterHypothecairBerichtPerceelRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterHypothecairBerichtPerceel($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kadasterEigendomsBerichtPerceel
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Find a 'Eigendomsbericht' by parcel details. Returns the result as a <BerichtObjectResultaat>. In addition to the structured result, a file of the specified format is returned. If the input matches more than one parcel, a list of the
     * parcels found is returned instead.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterEigendomsBerichtPerceelRequestType $parameters
     * @return \StructType\KadasterEigendomsBerichtPerceelResponseType|bool
     */
    public function kadasterEigendomsBerichtPerceel(\StructType\KadasterEigendomsBerichtPerceelRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterEigendomsBerichtPerceel($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kadasterEigendomsBerichtPostcode
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Find a 'Eigendomsbericht' by postcode and house number. Returns the result as a <BerichtObjectResultaat>. In addition to the structured result, a file of the specified format is returned. If the input matches more than one parcel, a
     * list of the parcels found is returned instead.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterEigendomsBerichtPostcodeRequestType $parameters
     * @return \StructType\KadasterEigendomsBerichtPostcodeResponseType|bool
     */
    public function kadasterEigendomsBerichtPostcode(\StructType\KadasterEigendomsBerichtPostcodeRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterEigendomsBerichtPostcode($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * kadasterUittrekselKadastraleKaartPerceelV2
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a 'Uittreksel Kadastrale Kaart' (a map showing the boundaries of a parcel and buildings on that parcel) in the specified format.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterUittrekselKadastraleKaartPerceelV2RequestType $parameters
     * @return \StructType\KadasterUittrekselKadastraleKaartPerceelV2ResponseType|bool
     */
    public function kadasterUittrekselKadastraleKaartPerceelV2(\StructType\KadasterUittrekselKadastraleKaartPerceelV2RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterUittrekselKadastraleKaartPerceelV2($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * kadasterUittrekselKadastraleKaartPostcodeV2
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a 'Uittreksel Kadastrale Kaart' (a map showing the boundaries of a parcel and buildings on that parcel) in the specified format.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterUittrekselKadastraleKaartPostcodeV2RequestType $parameters
     * @return \StructType\KadasterUittrekselKadastraleKaartPostcodeV2ResponseType|bool
     */
    public function kadasterUittrekselKadastraleKaartPostcodeV2(\StructType\KadasterUittrekselKadastraleKaartPostcodeV2RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterUittrekselKadastraleKaartPostcodeV2($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kadasterKadastraleKaartPerceel
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a 'Kadata WMS De Kadastrale Kaart' map in the specified format.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterKadastraleKaartPerceelRequestType $parameters
     * @return \StructType\KadasterKadastraleKaartPerceelResponseType|bool
     */
    public function kadasterKadastraleKaartPerceel(\StructType\KadasterKadastraleKaartPerceelRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterKadastraleKaartPerceel($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kadasterKadastraleKaartPostcode
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a 'Kadata WMS De Kadastrale Kaart' map in the specified format.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterKadastraleKaartPostcodeRequestType $parameters
     * @return \StructType\KadasterKadastraleKaartPostcodeResponseType|bool
     */
    public function kadasterKadastraleKaartPostcode(\StructType\KadasterKadastraleKaartPostcodeRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterKadastraleKaartPostcode($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * kadasterHypothecairBerichtPostcodeV2
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Find a 'Hypothecair bericht' by postcode and house number. If the input matches more than one parcel, a list of the parcels found is returned instead.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterHypothecairBerichtPostcodeV2RequestType $parameters
     * @return \StructType\KadasterHypothecairBerichtPostcodeV2ResponseType|bool
     */
    public function kadasterHypothecairBerichtPostcodeV2(\StructType\KadasterHypothecairBerichtPostcodeV2RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterHypothecairBerichtPostcodeV2($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * kadasterHypothecairBerichtPerceelV2
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Find a 'Hypothecair bericht' by parcel details.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterHypothecairBerichtPerceelV2RequestType $parameters
     * @return \StructType\KadasterHypothecairBerichtPerceelV2ResponseType|bool
     */
    public function kadasterHypothecairBerichtPerceelV2(\StructType\KadasterHypothecairBerichtPerceelV2RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterHypothecairBerichtPerceelV2($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kadasterKoopsommenOverzicht
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a koopsommenoverzicht (in English: real estate transactions overview), which is a list of all transactions of the past five years in the given postcode range.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterKoopsommenOverzichtRequestType $parameters
     * @return \StructType\KadasterKoopsommenOverzichtResponseType|bool
     */
    public function kadasterKoopsommenOverzicht(\StructType\KadasterKoopsommenOverzichtRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterKoopsommenOverzicht($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * kadasterV2GetKadastraalBerichtObjectByAdres
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Fetch a "KadastraalBerichtObject" using an address
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterV2GetKadastraalBerichtObjectByAdresRequestType $parameters
     * @return \StructType\KadasterV2GetKadastraalBerichtObjectByAdresResponseType|bool
     */
    public function kadasterV2GetKadastraalBerichtObjectByAdres(\StructType\KadasterV2GetKadastraalBerichtObjectByAdresRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterV2GetKadastraalBerichtObjectByAdres($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * kadasterV2GetKadastraalBerichtObjectByKadastraleAanduiding
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Fetch a "KadastraalBerichtObject" using a designation for the parcel
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterV2GetKadastraalBerichtObjectByKadastraleAanduidingRequestType $parameters
     * @return \StructType\KadasterV2GetKadastraalBerichtObjectByKadastraleAanduidingResponseType|bool
     */
    public function kadasterV2GetKadastraalBerichtObjectByKadastraleAanduiding(\StructType\KadasterV2GetKadastraalBerichtObjectByKadastraleAanduidingRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterV2GetKadastraalBerichtObjectByKadastraleAanduiding($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * kadasterV2GetKadastraalBerichtObjectByObjectId
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Fetch a "KadastraalBerichtObject" using its identifier
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterV2GetKadastraalBerichtObjectByObjectIdRequestType $parameters
     * @return \StructType\KadasterV2GetKadastraalBerichtObjectByObjectIdResponseType|bool
     */
    public function kadasterV2GetKadastraalBerichtObjectByObjectId(\StructType\KadasterV2GetKadastraalBerichtObjectByObjectIdRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterV2GetKadastraalBerichtObjectByObjectId($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * kadasterV2GetHypothecairBerichtObjectByAdres
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Fetch a "HypothecairBerichtObject" using an address
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterV2GetHypothecairBerichtObjectByAdresRequestType $parameters
     * @return \StructType\KadasterV2GetHypothecairBerichtObjectByAdresResponseType|bool
     */
    public function kadasterV2GetHypothecairBerichtObjectByAdres(\StructType\KadasterV2GetHypothecairBerichtObjectByAdresRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterV2GetHypothecairBerichtObjectByAdres($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * kadasterV2GetHypothecairBerichtObjectByKadastraleAanduiding
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Fetch a "HypothecairBerichtObject" using a designation for the parcel
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterV2GetHypothecairBerichtObjectByKadastraleAanduidingRequestType $parameters
     * @return \StructType\KadasterV2GetHypothecairBerichtObjectByKadastraleAanduidingResponseType|bool
     */
    public function kadasterV2GetHypothecairBerichtObjectByKadastraleAanduiding(\StructType\KadasterV2GetHypothecairBerichtObjectByKadastraleAanduidingRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterV2GetHypothecairBerichtObjectByKadastraleAanduiding($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * kadasterV2GetHypothecairBerichtObjectByObjectId
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Fetch a "HypothecairBerichtObject" using its identifier
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterV2GetHypothecairBerichtObjectByObjectIdRequestType $parameters
     * @return \StructType\KadasterV2GetHypothecairBerichtObjectByObjectIdResponseType|bool
     */
    public function kadasterV2GetHypothecairBerichtObjectByObjectId(\StructType\KadasterV2GetHypothecairBerichtObjectByObjectIdRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterV2GetHypothecairBerichtObjectByObjectId($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * kadasterV2GetUittrekselKadastraleKaartByAdres
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Fetch an "UittrekselKadastraleKaart" using an address
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterV2GetUittrekselKadastraleKaartByAdresRequestType $parameters
     * @return \StructType\KadasterV2GetUittrekselKadastraleKaartByAdresResponseType|bool
     */
    public function kadasterV2GetUittrekselKadastraleKaartByAdres(\StructType\KadasterV2GetUittrekselKadastraleKaartByAdresRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterV2GetUittrekselKadastraleKaartByAdres($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * kadasterV2GetUittrekselKadastraleKaartByKadastraleAanduiding
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Fetch an "UittrekselKadastraleKaart" using a designation for the parcel
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterV2GetUittrekselKadastraleKaartByKadastraleAanduidingRequestType $parameters
     * @return \StructType\KadasterV2GetUittrekselKadastraleKaartByKadastraleAanduidingResponseType|bool
     */
    public function kadasterV2GetUittrekselKadastraleKaartByKadastraleAanduiding(\StructType\KadasterV2GetUittrekselKadastraleKaartByKadastraleAanduidingRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterV2GetUittrekselKadastraleKaartByKadastraleAanduiding($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * kadasterV2GetUittrekselKadastraleKaartByObjectId
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Fetch an "UittrekselKadastraleKaart" using its identifier
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterV2GetUittrekselKadastraleKaartByObjectIdRequestType $parameters
     * @return \StructType\KadasterV2GetUittrekselKadastraleKaartByObjectIdResponseType|bool
     */
    public function kadasterV2GetUittrekselKadastraleKaartByObjectId(\StructType\KadasterV2GetUittrekselKadastraleKaartByObjectIdRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterV2GetUittrekselKadastraleKaartByObjectId($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kadasterV2GetKoopsommenOverzicht
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Fetch a list of "Koopsommen" using an address
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterV2GetKoopsommenOverzichtRequestType $parameters
     * @return \StructType\KadasterV2GetKoopsommenOverzichtResponseType|bool
     */
    public function kadasterV2GetKoopsommenOverzicht(\StructType\KadasterV2GetKoopsommenOverzichtRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterV2GetKoopsommenOverzicht($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kadasterV2GetBronDocument
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Fetch a "KadasterV2BronDocumentResponse"
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KadasterV2GetBronDocumentRequestType $parameters
     * @return \StructType\KadasterV2GetBronDocumentResponseType|bool
     */
    public function kadasterV2GetBronDocument(\StructType\KadasterV2GetBronDocumentRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kadasterV2GetBronDocument($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Returns the result
     * @see AbstractSoapClientBase::getResult()
     * @return \StructType\KadasterAddressCoordinatesResponseType|\StructType\KadasterBronDocumentResponseType|\StructType\KadasterEigendomsBerichtDocumentPerceelResponseType|\StructType\KadasterEigendomsBerichtDocumentPostcodeResponseType|\StructType\KadasterEigendomsBerichtPerceelResponseType|\StructType\KadasterEigendomsBerichtPerceelV2ResponseType|\StructType\KadasterEigendomsBerichtPostcodeResponseType|\StructType\KadasterEigendomsBerichtPostcodeV2ResponseType|\StructType\KadasterHypothecairBerichtPerceelResponseType|\StructType\KadasterHypothecairBerichtPerceelV2ResponseType|\StructType\KadasterHypothecairBerichtPerceelV3ResponseType|\StructType\KadasterHypothecairBerichtPostcodeResponseType|\StructType\KadasterHypothecairBerichtPostcodeV2ResponseType|\StructType\KadasterHypothecairBerichtPostcodeV3ResponseType|\StructType\KadasterKadastraleKaartPerceelResponseType|\StructType\KadasterKadastraleKaartPerceelV2ResponseType|\StructType\KadasterKadastraleKaartPostcodeResponseType|\StructType\KadasterKadastraleKaartPostcodeV2ResponseType|\StructType\KadasterKoopsommenOverzichtResponseType|\StructType\KadasterKoopsommenOverzichtV2ResponseType|\StructType\KadasterUittrekselKadastraleKaartPerceelResponseType|\StructType\KadasterUittrekselKadastraleKaartPerceelV2ResponseType|\StructType\KadasterUittrekselKadastraleKaartPerceelV3ResponseType|\StructType\KadasterUittrekselKadastraleKaartPostcodeResponseType|\StructType\KadasterUittrekselKadastraleKaartPostcodeV2ResponseType|\StructType\KadasterUittrekselKadastraleKaartPostcodeV3ResponseType|\StructType\KadasterV2GetBronDocumentResponseType|\StructType\KadasterV2GetHypothecairBerichtObjectByAdresResponseType|\StructType\KadasterV2GetHypothecairBerichtObjectByKadastraleAanduidingResponseType|\StructType\KadasterV2GetHypothecairBerichtObjectByObjectIdResponseType|\StructType\KadasterV2GetKadastraalBerichtObjectByAdresResponseType|\StructType\KadasterV2GetKadastraalBerichtObjectByKadastraleAanduidingResponseType|\StructType\KadasterV2GetKadastraalBerichtObjectByObjectIdResponseType|\StructType\KadasterV2GetKoopsommenOverzichtResponseType|\StructType\KadasterV2GetUittrekselKadastraleKaartByAdresResponseType|\StructType\KadasterV2GetUittrekselKadastraleKaartByKadastraleAanduidingResponseType|\StructType\KadasterV2GetUittrekselKadastraleKaartByObjectIdResponseType|\StructType\KadasterValueListGetMunicipalitiesResponseType|\StructType\KadasterValueListGetRangesResponseType
     */
    public function getResult()
    {
        return parent::getResult();
    }
}
