<?php

namespace ServiceType;

use \WsdlToPhp\PackageBase\AbstractSoapClientBase;

/**
 * This class stands for Route ServiceType
 * @subpackage Services
 */
class Route extends AbstractSoapClientBase
{
    /**
     * Sets the HeaderLogin SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param \StructType\HeaderLoginType $headerLogin
     * @param string $nameSpace
     * @param bool $mustUnderstand
     * @param string $actor
     * @return bool
     */
    public function setSoapHeaderHeaderLogin(\StructType\HeaderLoginType $headerLogin, $nameSpace = 'http://www.webservices.nl/soap/', $mustUnderstand = false, $actor = null)
    {
        return $this->setSoapHeader($nameSpace, 'HeaderLogin', $headerLogin, $mustUnderstand, $actor);
    }
    /**
     * Sets the HeaderAuthenticate SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param \StructType\HeaderAuthenticateType $headerAuthenticate
     * @param string $nameSpace
     * @param bool $mustUnderstand
     * @param string $actor
     * @return bool
     */
    public function setSoapHeaderHeaderAuthenticate(\StructType\HeaderAuthenticateType $headerAuthenticate, $nameSpace = 'http://www.webservices.nl/soap/', $mustUnderstand = false, $actor = null)
    {
        return $this->setSoapHeader($nameSpace, 'HeaderAuthenticate', $headerAuthenticate, $mustUnderstand, $actor);
    }
    /**
     * Method to call the operation originally named routePlannerGetRoute
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Get description and image for a route between two addresses
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\RoutePlannerGetRouteRequestType $parameters
     * @return \StructType\RoutePlannerGetRouteResponseType|bool
     */
    public function routePlannerGetRoute(\StructType\RoutePlannerGetRouteRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->routePlannerGetRoute($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named routePlannerInformationAddress
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Summary information about a route calculated between two addresses
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\RoutePlannerInformationAddressRequestType $parameters
     * @return \StructType\RoutePlannerInformationAddressResponseType|bool
     */
    public function routePlannerInformationAddress(\StructType\RoutePlannerInformationAddressRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->routePlannerInformationAddress($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named routePlannerDescriptionAddress
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Detailed information about a route calculated between two addresses
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\RoutePlannerDescriptionAddressRequestType $parameters
     * @return \StructType\RoutePlannerDescriptionAddressResponseType|bool
     */
    public function routePlannerDescriptionAddress(\StructType\RoutePlannerDescriptionAddressRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->routePlannerDescriptionAddress($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named routePlannerDescription
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a description of the fastest route between two postcodes. For every part of the route the drivetime in seconds and drivedistance in meters are given as well. If the english argument is true the description will be in english,
     * otherwise it will be in dutch.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\RoutePlannerDescriptionRequestType $parameters
     * @return \StructType\RoutePlannerDescriptionResponseType|bool
     */
    public function routePlannerDescription(\StructType\RoutePlannerDescriptionRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->routePlannerDescription($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named routePlannerDescriptionShortest
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a description of the shortest route between two postcodes. For every part of the route the drivetime in seconds and drivedistance in meters are given as well. If the english argument is true the description will be in
     * english, otherwise it will be in dutch.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\RoutePlannerDescriptionShortestRequestType $parameters
     * @return \StructType\RoutePlannerDescriptionShortestResponseType|bool
     */
    public function routePlannerDescriptionShortest(\StructType\RoutePlannerDescriptionShortestRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->routePlannerDescriptionShortest($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * routePlannerDescriptionCoordinatesRD
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a description of the route between two dutch postcodes, including the RD coordinates along the route. For every part of the route the drivetime in seconds and drivedistance in meters are given as well. The routetype can be
     * shortest or fastest. By default the fastest route will be calculated. If the english argument is true the description will be in english, otherwise it will be in dutch.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\RoutePlannerDescriptionCoordinatesRDRequestType $parameters
     * @return \StructType\RoutePlannerDescriptionCoordinatesRDResponseType|bool
     */
    public function routePlannerDescriptionCoordinatesRD(\StructType\RoutePlannerDescriptionCoordinatesRDRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->routePlannerDescriptionCoordinatesRD($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named routePlannerInformation
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns information (drivetime in seconds and drivedistance in meters) of the route between two postcodes. The routetype can be shortest or fastest. By default the fastest route will be calculated.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\RoutePlannerInformationRequestType $parameters
     * @return \StructType\RoutePlannerInformationResponseType|bool
     */
    public function routePlannerInformation(\StructType\RoutePlannerInformationRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->routePlannerInformation($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named routePlannerRDDescription
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a description of the route between two coordinates in the RD (Rijksdriehoeksmeting) coordinate system. For every part of the route the drivetime in seconds and drivedistance in meters are given as well. The description is
     * available in dutch and english, depending on the english parameter toggle. The fastest or shortest route can be calculated depending on theroutetype parameter.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\RoutePlannerRDDescriptionRequestType $parameters
     * @return \StructType\RoutePlannerRDDescriptionResponseType|bool
     */
    public function routePlannerRDDescription(\StructType\RoutePlannerRDDescriptionRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->routePlannerRDDescription($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named routePlannerRDInformation
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns the route distance and drive time between two coordinates in the RD (Rijksdriehoeksmeting) coordinate system. The fastest or shorted route can be calculated depending on the routetypeparameter.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\RoutePlannerRDInformationRequestType $parameters
     * @return \StructType\RoutePlannerRDInformationResponseType|bool
     */
    public function routePlannerRDInformation(\StructType\RoutePlannerRDInformationRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->routePlannerRDInformation($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * routePlannerRDDescriptionCoordinatesRD
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a description of the route between two coordinates in the RD (Rijksdriehoeksmeting) coordinate system, including the RD coordinates along the route. For every part of the route the drivetime in seconds and drivedistance in
     * meters are given as well. The fastest or shortest route can be calculated depending on the routetype parameter. The description is available in dutch and english, depending on the english parameter toggle.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\RoutePlannerRDDescriptionCoordinatesRDRequestType $parameters
     * @return \StructType\RoutePlannerRDDescriptionCoordinatesRDResponseType|bool
     */
    public function routePlannerRDDescriptionCoordinatesRD(\StructType\RoutePlannerRDDescriptionCoordinatesRDRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->routePlannerRDDescriptionCoordinatesRD($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * routePlannerInformationDutchAddress
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Summary information about a route calculated between two dutch-addresses
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\RoutePlannerInformationDutchAddressRequestType $parameters
     * @return \StructType\RoutePlannerInformationDutchAddressResponseType|bool
     */
    public function routePlannerInformationDutchAddress(\StructType\RoutePlannerInformationDutchAddressRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->routePlannerInformationDutchAddress($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * routePlannerDescriptionDutchAddress
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Detailed information about a route calculated between two dutch-addresses
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\RoutePlannerDescriptionDutchAddressRequestType $parameters
     * @return \StructType\RoutePlannerDescriptionDutchAddressResponseType|bool
     */
    public function routePlannerDescriptionDutchAddress(\StructType\RoutePlannerDescriptionDutchAddressRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->routePlannerDescriptionDutchAddress($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named routePlannerEUDescription
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a description of the route between two latitude/longitude coordinates in Europe. For every part of the route the drivetime and drivedistance are given as well. The description is available in several languages depending on
     * the language parameter. The fastest or shortest route is be calculated depending on the routetype parameter.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\RoutePlannerEUDescriptionRequestType $parameters
     * @return \StructType\RoutePlannerEUDescriptionResponseType|bool
     */
    public function routePlannerEUDescription(\StructType\RoutePlannerEUDescriptionRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->routePlannerEUDescription($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named routePlannerEUInformation
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns the route distance and drive time for the route between two latitude/longitude coordinates in Europe. The fastest or shortest route can be calculated depending on the routetype parameter.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\RoutePlannerEUInformationRequestType $parameters
     * @return \StructType\RoutePlannerEUInformationResponseType|bool
     */
    public function routePlannerEUInformation(\StructType\RoutePlannerEUInformationRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->routePlannerEUInformation($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * routePlannerEUDescriptionCoordinatesLatLon
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a description of the route between two latitude/longitude coordinates in Europe, including the latitude/longitude coordinates along the route. For every part of the route the drivetime in seconds and drivedistance in meters
     * are given as well. The routetype can be shortest or fastest. By default information on the fastest route will be returned. The description is available in several languages depending on the language parameter.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\RoutePlannerEUDescriptionCoordinatesLatLonRequestType $parameters
     * @return \StructType\RoutePlannerEUDescriptionCoordinatesLatLonResponseType|bool
     */
    public function routePlannerEUDescriptionCoordinatesLatLon(\StructType\RoutePlannerEUDescriptionCoordinatesLatLonRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->routePlannerEUDescriptionCoordinatesLatLon($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named routePlannerEUMap
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a map showing the route between two latitude/longitude coordinates in Europe.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\RoutePlannerEUMapRequestType $parameters
     * @return \StructType\RoutePlannerEUMapResponseType|bool
     */
    public function routePlannerEUMap(\StructType\RoutePlannerEUMapRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->routePlannerEUMap($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Returns the result
     * @see AbstractSoapClientBase::getResult()
     * @return \StructType\RoutePlannerDescriptionAddressResponseType|\StructType\RoutePlannerDescriptionCoordinatesRDResponseType|\StructType\RoutePlannerDescriptionDutchAddressResponseType|\StructType\RoutePlannerDescriptionResponseType|\StructType\RoutePlannerDescriptionShortestResponseType|\StructType\RoutePlannerEUDescriptionCoordinatesLatLonResponseType|\StructType\RoutePlannerEUDescriptionResponseType|\StructType\RoutePlannerEUInformationResponseType|\StructType\RoutePlannerEUMapResponseType|\StructType\RoutePlannerGetRouteResponseType|\StructType\RoutePlannerInformationAddressResponseType|\StructType\RoutePlannerInformationDutchAddressResponseType|\StructType\RoutePlannerInformationResponseType|\StructType\RoutePlannerRDDescriptionCoordinatesRDResponseType|\StructType\RoutePlannerRDDescriptionResponseType|\StructType\RoutePlannerRDInformationResponseType
     */
    public function getResult()
    {
        return parent::getResult();
    }
}
